| randomizer | R Documentation |
A dataset containing information about each challenge: protein, vegetables, equipment, style, time
data(randomizer)
This data frame contains the following columns:
seasonSeason number
episodeEpisode number
roundStage of the tournament: Qualifier semi-final, Qualifier final, Round of 32, Round of 16, Quarterfinals, Semifinals, Final
challengeVariable to help distinguish challenges within the same Coast & Round
coastEast or West
regionThe region depends on how many chefs start the competition. If there are 16 chefs, then the region is left blank. If there are 32 chefs, then the regions are A or B.
randomizer1First wheel of randomizer
randomizer2Second wheel of randomizer
randomizer3Third wheel of randomizer
randomizer4Fourth wheel of randomizer
timeLength of challenge. Unit is minutes
randomizer5Fifth wheel of randomizer
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse)
randomizer %>%
group_by(season,episode,challenge,coast) %>%
filter(round == "Semi-final")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.