| seeds | R Documentation |
A dataset containing game-related information on each Chef for each season.
data(seeds)
This data frame contains the following columns:
chefChef name (full name)
seasonSeason number
seedSeed within their section of the bracket: values of 1 through 8. Chefs that played in the qualifiers but didn't make the final bracket will have seeds of 8.2, 8.3, or 8.4.
coastAre they East or West Coast?
regionThe region depends on how many chefs start the competition. If there are 16 chefs, then the region is left blank. If there are 32 chefs, then the regions are A or B.
https://en.wikipedia.org/wiki/Tournament_of_Champions_(TV_series)
library(tidyverse)
seeds %>%
filter(season == 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.